#!/bin/bash

# Get Debian's Linux source package.
DEB_DIR=from_debian

if [ ! -d "$DEB_DIR" ] ; then
    # We don't have the source package yet.
    mkdir "$DEB_DIR"
    cd "$DEB_DIR"
    apt-get --target-release wheezy --download-only source linux
    cd ..
fi

# Get deblob scripts.
LL_SVN=http://www.fsfla.org/svn/fsfla/software/linux-libre/scripts/
svn export ${LL_SVN}deblob-check
svn export ${LL_SVN}deblob-3.2
chmod +x deblob-*

# We're going to deblob the unpatched source.
tar -xf "$DEB_DIR"/*.orig.*
cd linux-3.2.*

# Has to be forced, as Debian has already cleaned almost all firmware out.
../deblob-3.2 --force
echo TODO: deblob-check
echo TODO: deblob-check diff.gz?

# Patch out LLs EXTRAVERSION
sed -i 's/EXTRAVERSION =.*/EXTRAVERSION =/g' Makefile

# Wrap it back up.
cd ..
TAR_FILE=$(basename "$DEB_DIR"/*.orig.*)
tar -cJf "$TAR_FILE" linux-3.2.*

# Fix checksums.
SHA1SUM=$(sha1sum *.orig.* | cut -d ' ' -f 1)
SHA256SUM=$(sha256sum *.orig.* | cut -d ' ' -f 1)
MD5SUM=$(md5sum *.orig.* | cut -d ' ' -f 1)

echo SHA1=$SHA1SUM
echo SHA256=$SHA256SUM
echo MD5=$MD5SUM

cp "$DEB_DIR"/*.debian.* .
cp "$DEB_DIR"/*dsc .
sed -i -e 's,^ [[:alnum:]]\{40\}\( [0-9]\+ '${TAR_FILE}'\), '${SHA1SUM}'\1,' *dsc
sed -i -e 's,^ [[:alnum:]]\{64\}\( [0-9]\+ '${TAR_FILE}'\), '${SHA256SUM}'\1,' *dsc
sed -i -e 's,^ [[:alnum:]]\{32\}\( [0-9]\+ '${TAR_FILE}'\), '${MD5SUM}'\1,' *dsc

# Fix file size.
SIZE=$(ls -l *.orig.* | cut -d ' ' -f 5)
sed -i -e 's,\(^ [[:alnum:]]\{40\} \)[0-9]\+\( '${TAR_FILE}'\), \1'${SIZE}'\2,' *dsc
sed -i -e 's,\(^ [[:alnum:]]\{64\} \)[0-9]\+\( '${TAR_FILE}'\), \1'${SIZE}'\2,' *dsc
sed -i -e 's,\(^ [[:alnum:]]\{32\} \)[0-9]\+\( '${TAR_FILE}'\), \1'${SIZE}'\2,' *dsc

# Extract source package.
#dpkg-source --no-check -x *dsc
tar -xf *.debian.* -C linux-3.2*

# Check Debian patches for blobs.
find linux-3.2.*/debian/patches -iname '*.patch' -exec ./deblob-check --list-blobs {} \+

sed -i \
  -e '/features\/all\/drivers-media-dvb-usb-af9005-request_firmware.patch/d' \
  -e '/features\/all\/sound-pci-cs46xx-request_firmware.patch/d' \
  -e '/bugfix\/all\/net-e100-ucode-is-optional-in-some-cases.patch/d' \
  -e '/bugfix\/all\/cassini-Make-missing-firmware-non-fatal.patch/d' \
  -e '/bugfix\/all\/firmware-remove-redundant-log-messages-from-drivers.patch/d' \
  -e '/features\/all\/drm\/drm-3.4.patch/d' \
  -e '/features\/all\/drm\/drm-i915-revert-switch-to-simple_open.patch/d' \
  -e '/features\/all\/drm\/Revert-VM-add-vm_mmap-helper-function.patch/d' \
  -e '/features\/all\/drm\/drm-revert-part-of-2c9ede55ecec58099b72e4bb8eab719f3.patch/d' \
  -e '/features\/all\/drm\/Revert-drm-base-prime-dma-buf-support-v5.patch/d' \
  -e '/features\/all\/drm\/revert-vm-add-vm_munmap-helper-function.patch/d' \
  -e '/bugfix\/x86\/drm-i915-Only-kick-out-vesafb-if-we-takeover-the-fbc.patch/d' \
  -e '/bugfix\/ia64\/nouveau-ACPI-support-is-dependent-on-X86.patch/d' \
  -e '/bugfix\/x86\/drm-i915-panel-invert-brightness-via-parameter.patch/d' \
  -e '/bugfix\/x86\/drm-i915-panel-invert-brightness-via-quirk.patch/d' \
  -e '/bugfix\/x86\/drm-i915-panel-invert-brightness-acer-aspire-5734z.patch/d' \
  -e '/bugfix\/x86\/drm-i915-add-quirk_invert_brightness-for-ncr-machine.patch/d' \
  -e '/bugfix\/x86\/drm-i915-add-quirk-to-invert-brightness-on-emachines-g725.patch/d' \
  -e '/bugfix\/x86\/drm-i915-add-quirk-to-invert-brightness-on-emachines-e725.patch/d' \
  -e '/bugfix\/x86\/drm-i915-add-quirk-to-invert-brightness-on-packard-bell-ncl20.patch/d' \
  -e '/bugfix\/all\/drm-nouveau-fix-init-with-agpgart-uninorth.patch/d' \
  -e '/bugfix\/x86\/drm-i915-Close-race-between-processing-unpin-task-an.patch/d' \
  -e '/bugfix\/all\/drm-radeon-dce32-use-fractional-fb-dividers-for-high.patch/d' \
  -e '/bugfix\/all\/drm-radeon-fix-amd-afusion-gpu-setup-aka-sumo-v2.patch/d' \
  -e '/bugfix\/all\/i915-ensure-that-VGA-plane-is-disabled.patch/d' \
  -e '/bugfix\/all\/drm-radeon-add-connector-table-for-SAM440ep-embedded.patch/d' \
  -e '/bugfix\/all\/drm-radeon-add-connector-table-for-Mac-G4-Silver.patch/d' \
  -e '/bugfix\/x86\/drm-i915-Only-increment-the-user-pin-count-after-suc.patch/d' \
  -e '/bugfix\/x86\/drm-i915-Disable-AsyncFlip-performance-optimisations.patch/d' \
  -e '/bugfix\/x86\/drm-i915-dump-UTS_RELEASE-into-the-error_state.patch/d' \
  -e '/bugfix\/x86\/drm-i915-Unconditionally-initialise-the-interrupt-wo.patch/d' \
  -e '/bugfix\/all\/drm-fix-drm_ioctl_mode_getfb-handle-leak.patch/d' \
  linux-3.2*/debian/patches/series

sed -i \
  -e '/features\/all\/rt\/0314-drm-i915-drop-trace_i915_gem_ring_dispatch-on-rt.patch/d' \
  linux-3.2*/debian/patches/series-rt

sed -i \
  -e '/hid-hyperv/d' \
  linux-3.2*/debian/installer/modules/hyperv-modules

echo TODO: add README.gNewSense
echo TODO: update debian/control
echo TODO: update debian/changelog
echo TODO: update debian/config/defines
